Learn R Programming

gluvarpro (version 7.0)

avggvp: average mean

Description

Generic function for the arithmetic mean and the standard deviation.

Usage

avggvp(x, var = "glucose", sd = FALSE)

Value

A numeric value containing the mean value or a character value containing the mean value and the standard deviation.

Arguments

x

Data-set with data frame format containing three columns:

date: date of the observation with format yyyy/mm/dd.

time: time of the observation with 24 hour format hh:mm:ss.

glucose or variability measure: glucose value or glucose variability measure.

var

Character value with variable to calculate the mean value and the standard deviation. Permitted values are glucose, adrr, lauc, hauc, auc, lbgi, hbgi, bgi, conga, cv, iqr, ji, li, ge, lmage, hmage, mage, mean, mv, sd, lpstr, hpstr, npstr and pstr. Default value is glucose.

sd

Logical value to calculate the standard deviation. Default value is FALSE.

Author

Sergio Contador.

References

Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988) The New S Language. Wadsworth & Brooks/Cole.

Examples

Run this code
data("datagvp1")
avggvp(datagvp1)

Run the code above in your browser using DataLab