Learn R Programming

gluvarpro (version 7.0)

cvgvp: percentage coefficient of variation

Description

Percentage coefficient of variation is a measure of glycemic variability defined as the ratio of the standard deviation to the mean.

Usage

cvgvp(x, t = 24)

Value

A data frame containing the cv values.

Arguments

x

Data-set with data frame format containing three columns:

date: date of the observation with format yyyy/mm/dd.

time: time of the observation with 24 hour format hh:mm:ss.

glucose: glucose value of the observation.

t

Numeric value with interval for calculating the measurement. Permitted values are 4, 6, 8, 12 and 24 hours. Default value of 24 hours.

Author

Sergio Contador.

References

Everitt, Brian (1998). The Cambridge Dictionary of Statistics. Cambridge, UK New York: Cambridge University Press.

See Also

meangvp(x, t = 24)

sdgvp(x, t = 24)

Examples

Run this code
data("datagvp1")
cvgvp(datagvp1)

Run the code above in your browser using DataLab