powered by
Percentage coefficient of variation is a measure of glycemic variability defined as the ratio of the standard deviation to the mean.
cvgvp(x, t = 24)
A data frame containing the cv values.
Data-set with data frame format containing three columns:
date: date of the observation with format yyyy/mm/dd.
time: time of the observation with 24 hour format hh:mm:ss.
glucose: glucose value of the observation.
Numeric value with interval for calculating the measurement. Permitted values are 4, 6, 8, 12 and 24 hours. Default value of 24 hours.
Sergio Contador.
Everitt, Brian (1998). The Cambridge Dictionary of Statistics. Cambridge, UK New York: Cambridge University Press.
meangvp(x, t = 24)
sdgvp(x, t = 24)
data("datagvp1") cvgvp(datagvp1)
Run the code above in your browser using DataLab