Arithmetic mean is an average measure of glycemia that calculates the sum of a set of data values divided by the number of data values in the data-set.
Usage
meangvp(x, t = 24)
Value
A data frame containing the mean values.
Arguments
x
Data-set with data frame format containing three columns:
date: date of the observation with format yyyy/mm/dd.
time: time of the observation with 24 hour format hh:mm:ss.
glucose: glucose value of the observation.
t
Numeric value with interval for calculating the measurement. Permitted values are 4, 6, 8, 12 and 24 hours. Default value of 24 hours.
Author
Sergio Contador.
References
Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988). The New S Language. Wadsworth & Brooks/Cole.